#!/usr/bin/env bash
export PYTHONPATH=/builds/esde/toar-data/toardb_fastapi/

# run make command
pytest tests 2>&1 | tee test_results.out
IS_FAILED=$?

# extract if tests passed or not
TEST_FAILED="$(grep 'failed' test_results.out | (grep -oP '\d*'))"
if [ -n "$TEST_FAILED" ]
then
    set $TEST_FAILED
    TEST_FAILED=$1
else
    TEST_FAILED=0
fi
TEST_PASSED="$(grep 'passed' test_results.out | (grep -oP '\d*'))"
set $TEST_PASSED
TEST_PASSED=$1

if [[ -z "$TEST_FAILED" ]]; then
    TEST_FAILED=0
fi

# calculate metrics
let "SUM=${TEST_FAILED}+${TEST_PASSED}"
let "TEST_PASSED_RATIO=${TEST_PASSED}*100/${SUM}"

# report
if [[ ${IS_FAILED} == 0 ]]; then
    if [[ ${TEST_PASSED_RATIO} -lt 100 ]]; then
        echo "only ${TEST_PASSED_RATIO}% passed"
        echo "incomplete" > status.txt
        echo "${TEST_PASSED_RATIO}%25 passed" > incomplete.txt
        if [[ ${TEST_PASSED_RATIO} -lt ${FAILURE_THRESHOLD} ]]; then
            echo -e "\033[1;31monly ${TEST_PASSED_RATIO}% passed!!\033[0m"
            exit 1
        fi
    else
        echo "passed"
        echo "success" > status.txt
    fi
    exit 0
else
    echo "not passed"
    exit 1
fi

