#!/bin/bash

PAGES_INFO_URL=https://toar-data-dev.fz-juelich.de/api/v2
#activate this to get governance information of geolocation-urls
#PAGES_INFO_URL=http://127.0.0.1:8000

# get Geolocation URLs
curl "${PAGES_INFO_URL}/geolocation_urls/" > geolocation_urls.json
# prepare documentation for pages
python3 prepare_geolocation_urls.py geolocation_urls.json
# get information from automatic documentation
curl "${PAGES_INFO_URL}/openapi.json" > openapi.json
# prepare documentation for pages
python3 prepare_openapi_json.py openapi.json 
# convert OpenAPI format to Markdown
openapi-markdown --skip-info -i sample.json

# also get controlled_vocabulary
curl "${PAGES_INFO_URL}/controlled_vocabulary/" >controlled_vocabulary.json
# giving credit to torsimany (although it was not working, it was a good starting point)
torsimany controlled_vocabulary.json
torsimany geolocation_urls.json
# some more pretty printing for the "tables"
cat controlled_vocabulary.markdown | sed -E 's/\], \[/\],  \n \[/g' | sed -E 's/\[\[/\[  \n \[/g' | sed -E 's/#/####/g' >controlled_vocabulary.md


# last pretty print changes for pages
(
cat <<'EOF'
# TOAR II Database

### Models

EOF
) > sample_header.md
(
cat <<'EOF'


## REST API

EOF
) > sample_rest_header.md
sed '1,/^### Models$/d' sample.md >sample_models.md
sed '/^### Models$/Q' sample.md >sample_rest.md
(
cat <<'EOF'


## Controlled Vocabulary

EOF
) > controlled_vocabulary_header.md

cat sample_header.md sample_models.md geolocation_urls.md controlled_vocabulary_header.md controlled_vocabulary.md sample_rest_header.md sample_rest.md >../docs/toardb_fastapi.md
rm controlled* geolocation* openapi.json

## shared tables for documentation (toar-data-landing-page)
# - station_location.md
# - type_of_area.md
# - type.md
# - toar1_category.md
# - components_table.md
# - stationmetaglobal.md
# - combined_quality_flags.md
# - single_quality_flags.md
# - validated_quality_flags.md
# - preliminary_quality_flags.md

export PYTHONPATH=../toardb/utils/TOAR_Ontology:$PYTHONPATH
source ../toardb/utils/TOAR_Ontology/venv_onto/bin/activate
python tables_from_ontology.py
# next command not completely ready yet
./prep_tables.sh
#rm sample*
