import TOARII_ontology
import requests

TOAR_SERVICE_URL='https://toar-data.fz-juelich.de/api/v2/'
ontology_link = TOAR_SERVICE_URL + 'ontology'
convoc_link = TOAR_SERVICE_URL + 'controlled_vocabulary'

# get TOAR-II-Ontology (from web-site)
onto = TOARII_ontology.TOAR_Ontology(ontology_link)

def get_entry_definition(sclass, entrystr):
    # get ID of class StationMeta
    superclass=onto.get_class(sclass)

    # get classes defining attributes of superclass (subclasses of superclass!)
    dlclass=onto.get_class(entrystr, superclass=superclass)
    entry_definition=onto.get_class_definition(dlclass)
    return entry_definition


def get_table_definitions(classlabel):
    table_dict = {}
    dlclass=onto.get_class(classlabel)
    table_dict = onto.get_entries_with_definition(dlclass)
    return table_dict


def save_table_for_documentation(outfile, table, ordering):
    with open(outfile, 'w') as f:
        for key in ordering:
            print(f"{key} | {table[key]}", file=f)


# UG03 table 4.2
table_dict = {}
ordering = ['country', 'state', 'timezone']
for entry in ordering:
    table_dict[entry] = get_entry_definition('StationMeta',entry)
save_table_for_documentation("station_location.md", table_dict, ordering)

# UG03 table 4.3
ordering = ['Urban', 'RuralLowElevation', 'RuralHighElevation', 'Unclassified']
table_dict = get_table_definitions('toar1_category')
save_table_for_documentation("toar1_category.md", table_dict, ordering)

# UG03 table 4.4
ordering = ['Traffic', 'Industrial', 'Background']
table_dict = get_table_definitions('type_of_environment')
save_table_for_documentation("type.md", table_dict, ordering)

# UG03 table 4.5
ordering = ['Urban', 'Suburban', 'Rural']
table_dict = get_table_definitions('type_of_area')
save_table_for_documentation("type_of_area.md", table_dict, ordering)

# UG03 table 5.1
# we are showing a combined view here (is this needed? do we really need *internal* flag values?)
# This table cannot be created from source (or new idea needed!)

# UG03 table 5.2
# we are showing a combined view here (is this needed? do we really need *internal* flag values?)
# the following was (hard) copied from data/crud.py -- should be automatically created!
# https://gitlab.jsc.fz-juelich.de/esde/toar-data/toardb_fastapi/-/blob/dde8bee87b9e91f35b9bab953fbf0877303db468/toardb/data/crud.py#L41-75
# definition of aggregated_flags:
# agg. flag | composition of unique flags
# ----------|----------------------------
# 100       | 0-6
# 101       | 0-2
# 102       | 3-5
# 103       | 0, 1, 3, 4
# 104       | 2, 5, 6
# 110       | 10-16
# 111       | 10-12
# 112       | 13-16
# 120       | 20-28
# 121       | 20-23
# 122       | 24-28
# 130       | 10-28 (since 17-19 is undefined: 10-16, 20-28)
# 131       | 10-12, 20-23
# 132       | 13-16, 24-28
# 140       | 7, 16, 28
filter_dict = { 100: [ 0,  1,  2,  3,  4,  5,  6],
                101: [ 0,  1,  2],
                102: [ 3,  4,  5],
                103: [ 0,  1,  3,  4],
                104: [ 2,  5,  6],
                110: [10, 11, 12, 13, 14, 15, 16],
                111: [10, 11, 12],
                112: [13, 14, 15, 16],
                120: [20, 21, 22, 23, 24, 25, 26, 27, 28],
                121: [20, 21, 22, 23],
                122: [24, 25, 26, 27, 28],
                130: [10, 11, 12, 13, 14, 15, 16,
                      20, 21, 22, 23, 24, 25, 26, 27, 28],
                131: [10, 11, 12,
                      20, 21, 22, 23],
                132: [13, 16, 24, 25, 26, 27, 28],
                140: [ 7, 16, 28] }
ordering = ['AllOK', 'ValidatedOK', 'PreliminaryOK', 'NotModifiedOK', 'ModifiedOK',
            'AllQuestionable', 'ValidatedQuestionable', 'PreliminaryQuestionable', 
            'AllErroneous', 'ValidatedErroneous', 'PreliminaryErroneous',
            'AllQuestionableOrErroneous', 'ValidatedQuestionableOrErroneous',
            'PreliminaryQuestionableOrErroneous', 'NotChecked']
table_dict = get_table_definitions('flags')
convoc_list = requests.get(f"{convoc_link}/Data Flag").json()
flags_dict = {}
flags_dict_inverse = {}
for flag in convoc_list:
    flags_dict[flag[0]] = flag[1]
    flags_dict_inverse[flag[1]] = flag[0]
with open("combined_quality_flags.md", 'w') as f:
    for key in ordering:
        combined_list = ", ".join([ flags_dict[flag] for flag in filter_dict[flags_dict_inverse[key]] ])
        print(f"{flags_dict_inverse[key]} | {key} | {table_dict[key]} | {combined_list}", file=f)

# UG03 table 5.3
# we are showing a combined view here (is this needed? do we really need *internal* flag values?)
ordering = ['OKValidatedVerified', 'OKValidatedQCPassed', 'OKValidatedModified', 'OKPreliminaryVerified',
            'OKPreliminaryQCPassed', 'OKPreliminaryModified', 'OKEstimated', 'OKPreliminaryNotChecked',
            'QuestionableValidatedConfirmed', 'QuestionableValidatedConfirmed', 'QuestionableValidatedFlagged',
            'QuestionablePreliminaryConfirmed', 'QuestionablePreliminaryUnconfirmed',
            'QuestionablePreliminaryFlagged', 'QuestionablePreliminaryNotChecked',
            'ErroneousValidatedConfirmed', 'ErroneousValidatedUnconfirmed', 'ErroneousValidatedFlagged1',
            'ErroneousValidatedFlagged2', 'ErroneousPreliminaryConfirmed', 'ErroneousPreliminaryUnconfirmed',
            'ErroneousPreliminaryFlagged1', 'ErroneousPreliminaryFlagged1', 'ErroneousPreliminaryNotChecked',
            'MissingValue', 'UnknownQualityStatus' ]
table_dict = get_table_definitions('flags')
with open("single_quality_flags.md", 'w') as f:
    for key in ordering:
        print(f"{flags_dict_inverse[key]} | {key} | {table_dict[key]}", file=f)

# UG03 table 5.4/5.5
# (is this needed? do we really need *internal* flag values?)
# the following was (hard) copied from data/crud.py
#                      preliminary  provider           toarqc            combined
combined_flag_matrix = {( False,       'OK',           'OK')           : 'OKValidatedQCPassed',
                        ( False,       'OK',           'Questionable') : 'QuestionableValidatedFlagged',
                        ( False,       'OK',           'Erroneous')    : 'ErroneousValidatedFlagged1',
                        ( False,       'Questionable', 'OK')           : 'QuestionableValidatedUnconfirmed',
                        ( False,       'Questionable', 'Questionable') : 'QuestionableValidatedConfirmed',
                        ( False,       'Questionable', 'Erroneous')    : 'ErroneousValidatedFlagged2',
                        ( False,       'Erroneous',    'OK')           : 'ErroneousValidatedUnconfirmed',
                        ( False,       'Erroneous',    'Questionable') : 'ErroneousValidatedConfirmed',
                        ( False,       'Erroneous',    'Erroneous')    : 'ErroneousValidatedConfirmed',
                        ( True,        'OK',           'OK')           : 'OKPreliminaryQCPassed',
                        ( True,        'OK',           'Questionable') : 'QuestionablePreliminaryFlagged',
                        ( True,        'OK',           'Erroneous')    : 'ErroneousPreliminaryFlagged1',
                        ( True,        'Questionable', 'OK')           : 'QuestionablePreliminaryUnconfirmed',
                        ( True,        'Questionable', 'Questionable') : 'QuestionablePreliminaryConfirmed',
                        ( True,        'Questionable', 'Erroneous')    : 'ErroneousPreliminaryFlagged2',
                        ( True,        'Erroneous',    'OK')           : 'ErroneousPreliminaryUnconfirmed',
                        ( True,        'Erroneous',    'Questionable') : 'ErroneousPreliminaryConfirmed',
                        ( True,        'Erroneous',    'Erroneous')    : 'ErroneousPreliminaryConfirmed'}
#                             provider        toarqc         combined
nrt_combined_flag_matrix = {( 'OK',           'OK')        : 'OKPreliminaryNotChecked',
                            ( 'Questionable', 'OK')        : 'QuestionablePreliminaryNotChecked',
                            ( 'Erroneous',    'OK')        : 'ErroneousPreliminaryNotChecked',
                            ( 'OK',           'Erroneous') : 'ErroneousPreliminaryFlagged1',
                            ( 'Questionable', 'Erroneous') : 'ErroneousPreliminaryFlagged2',
                            ( 'Erroneous',    'Erroneous') : 'Erroneous_Preliminary_Confirmed'}
single_flags = [ 'OK', 'Questionable', 'Erroneous' ]
with open("validated_quality_flags.md", 'w') as f:
    print(" | **toarqc**", file=f)
    print(f"**provider** | {' | '.join(flag for flag in single_flags)}", file=f)
    for provider in single_flags:
        combined_list = ' | '.join(combined_flag_matrix[(False, provider,toarqc)] for toarqc in single_flags )
        print(f"{provider} | {combined_list}", file=f)

with open("preliminary_quality_flags.md", 'w') as f:
    print(" | **toarqc**", file=f)
    print(f"**provider** | OK | Questionable | Erroneous | NotChecked", file=f)
    for provider in single_flags:
        combined_list = ' | '.join(combined_flag_matrix[(True, provider,toarqc)] for toarqc in single_flags )
        combined_list += f" | {nrt_combined_flag_matrix[(provider, 'OK')]}"
        print(f"{provider} | {combined_list}", file=f)

