--
-- toardb/extension/toar_controlled_vocabulary/toar_controlled_vocabulary--0.7.4--0.7.5.sql
--
-- [Step to install]
--
-- 1. 
--

-- INSTALL VERSION: '0.7.5'

-- complain if script is sourced in psql, rather than via CREATE EXTENSION
\echo Use "CREATE/ALTER EXTENSION toar_controlled_vocabulary" to load this file. \quit

-- still to do:
-- How to set convoc_schema to result from SELECT:
-- SELECT table_schema INTO convoc_schema FROM information_schema.tables WHERE table_name='df_vocabulary';

SET SCHEMA 'toar_convoc';

-- Roles
-- =====

-- Role Codes

INSERT INTO RC_vocabulary (enum_val, enum_str, enum_display_str) VALUES
    (7, 'Stakeholder', 'stakeholder'),
    (8, 'RightsHolder', 'rights holder');


-- Annotation
-- ==========

-- Kind of Annotation

INSERT INTO AK_vocabulary (enum_val, enum_str, enum_display_str) VALUES
   (2, 'Curator', 'curator comment');


-- Stationmeta
-- ===========

-- Station Landcover Types

ALTER TABLE DL_vocabulary RENAME TO LC_vocabulary;

DELETE FROM LC_vocabulary WHERE enum_val >= 0;

INSERT INTO LC_vocabulary (enum_val, enum_str, enum_display_str) VALUES
    (  0, 'NoData', '0 (No Data)'),
    ( 10, 'CroplandRainfed', '10 (Cropland, rainfed)'),
    ( 11, 'CroplandRainfedHerbaceousCover', '11 (Cropland, rainfed, herbaceous cover)'),
    ( 12, 'CroplandRainfedTreeOrShrubCover', '12 (Cropland, rainfed, tree or shrub cover)'),
    ( 20, 'CroplandIrrigated', '20 (Cropland, irrigated or post-flooding)'),
    ( 30, 'MosaicCropland', '30 (Mosaic cropland (>50%) / natural vegetation (tree, shrub, herbaceous cover) (<50%))'),
    ( 40, 'MosaicNaturalVegetation', '40 (Mosaic natural vegetation (tree, shrub, herbaceous cover) (>50%) / cropland (<50%))'),
    ( 50, 'TreeBroadleavedEvergreenClosedToOpen', '50 (Tree cover, broadleaved, evergreen, closed to open (>15%))'),
    ( 60, 'TreeBroadleavedDeciduousClosedToOpen', '60 (Tree cover, broadleaved, deciduous, closed to open (>15%))'),
    ( 61, 'TreeBroadleavedDeciduousClosed', '61 (Tree cover, broadleaved, deciduous, closed (>40%))'),
    ( 62, 'TreeBroadleavedDeciduousOpen', '62 (Tree cover, broadleaved, deciduous, open (15-40%))'),
    ( 70, 'TreeNeedleleavedEvergreenClosedToOpen', '70 (Tree cover, needleleaved, evergreen, closed to open (>15%))'),
    ( 71, 'TreeNeedleleavedEvergreenClosed', '71 (Tree cover, needleleaved, evergreen, closed (>40%))'),
    ( 72, 'TreeNeedleleavedEvergreenOpen', '72 (Tree cover, needleleaved, evergreen, open (15-40%))'),
    ( 80, 'TreeNeedleleavedDeciduousClosedToOpen', '80 (Tree cover, needleleaved, deciduous, closed to open (>15%))'),
    ( 81, 'TreeNedleleavedDeciduousClosed', '81 (Tree cover, needleleaved, deciduous, closed (>40%))'),
    ( 82, 'TreeNeedleleavedDeciduousOpen', '82 (Tree cover, needleleaved, deciduous, open (15-40%))'),
    ( 90, 'TreeMixed', '90 (Tree cover, mixed leaf type (broadleaved and needleleaved))'),
    (100, 'MosaicTreeAndShrub', '100 (Mosaic tree and shrub (>50%) / herbaceous cover (<50%))'),
    (110, 'MosaicHerbaceous', '110 (Mosaic herbaceous cover (>50%) / tree and shrub (<50%))'),
    (120, 'Shrubland', '120 (Shrubland)'),
    (121, 'ShrublandEvergreen', '121 (Evergreen shrubland)'),
    (122, 'ShrublandDeciduous', '122 (Deciduous shrubland)'),
    (130, 'Grassland', '130 (Grassland)'),
    (140, 'LichensAndMosses', '140 (Lichens and mosses)'),
    (150, 'SparseVegetation', '150 (Sparse vegetation (tree, shrub, herbaceous cover) (<15%))'),
    (151, 'SparseTree', '151 (Sparse tree (<15%))'),
    (152, 'SparseShrub', '152 (Sparse shrub (<15%))'),
    (153, 'SparseHerbaceous', '153 (Sparse herbaceous cover (<15%))'),
    (160, 'TreeCoverFloodedFreshOrBrakishWater', '160 (Tree cover, flooded, fresh or brakish water)'),
    (170, 'TreeCoverFloodedSalineWater', '170 (Tree cover, flooded, saline water)'),
    (180, 'ShrubOrHerbaceousCoverFlooded', '180 (Shrub or herbaceous cover, flooded, fresh/saline/brakish water)'),
    (190, 'Urban', '190 (Urban areas)'),
    (200, 'BareAreas', '200 (Bare areas)'),
    (201, 'BareAreasConsolidated', '201 (Consolidated bare areas)'),
    (202, 'BareAreasUnconsolidated', '202 (Unconsolidated bare areas)'),
    (210, 'Water', '210 (Water bodies)'),
    (220, 'SnowAndIce', '220 (Permanent snow and ice)');


-- Timeseries: Additional Metadata
-- ===============================

-- Absorption Cross Section

CREATE TABLE IF NOT EXISTS CS_vocabulary (
    enum_val         INT NOT NULL,
    enum_str         character varying(128) NOT NULL,
    enum_display_str character varying(128) NOT NULL,
    PRIMARY KEY(enum_val, enum_str),
    CONSTRAINT cs_enum_val_unique UNIQUE (enum_val)
);

INSERT INTO CS_vocabulary (enum_val, enum_str, enum_display_str) VALUES
    (0, 'Hearn1961', 'Hearn 1961'),
    (1, 'CCQM.O3.2019', 'CCQM values of 2019 for O3');

-- Sampling Type (KS: Kind of Sampling)

CREATE TABLE IF NOT EXISTS KS_vocabulary (
    enum_val         INT NOT NULL,
    enum_str         character varying(128) NOT NULL,
    enum_display_str character varying(128) NOT NULL,
    PRIMARY KEY(enum_val, enum_str),
    CONSTRAINT ks_enum_val_unique UNIQUE (enum_val)
);

INSERT INTO KS_vocabulary (enum_val, enum_str, enum_display_str) VALUES
    (0, 'Continuous', 'continuous'),
    (1, 'Filter', 'filter'),
    (2, 'Flask', 'flask');

-- Calibration Type

CREATE TABLE IF NOT EXISTS CT_vocabulary (
    enum_val         INT NOT NULL,
    enum_str         character varying(128) NOT NULL,
    enum_display_str character varying(128) NOT NULL,
    PRIMARY KEY(enum_val, enum_str),
    CONSTRAINT ct_enum_val_unique UNIQUE (enum_val)
);

INSERT INTO CT_vocabulary (enum_val, enum_str, enum_display_str) VALUES
    (0, 'Automatic', 'automatic'),
    (1, 'Manual', 'manual');

