#!/bin/bash
# for running: uvicorn toardb.toardb:app --reload

curl http://127.0.0.1:8000/variables/?limit=3
curl http://127.0.0.1:8000/variables/id/2
curl http://127.0.0.1:8000/variables/id/99
curl http://127.0.0.1:8000/variables/CO
curl -X POST -H "Content-Type:application/json" -d '{"name": "sabinene", "longname": "sabinene", "displayname": "Sabinene", "cf_standardname": "mole_fraction_of_sabinene_in_air", "units": "nmol mol-1", "chemical_formula": "C10H16"}' http://127.0.0.1:8000/variables/

curl http://127.0.0.1:8000/contacts/organisations/
curl http://127.0.0.1:8000/contacts/organisations/id/36
curl http://127.0.0.1:8000/contacts/organisations/id/99
curl http://127.0.0.1:8000/contacts/organisations/UBA
curl -X POST -H "Content-Type:application/json" -d '{"organisation": {"name": "FZJ", "longname": "Forschungszentrum Test", "kind": "Research", "city": "Jülich", "postcode": "52425", "street_address": "Wilhelm-Johnen-Straße", "country": "DE", "homepage": "https://www.fz-juelich.de"}}' http://127.0.0.1:8000/contacts/organisations/
curl http://127.0.0.1:8000/contacts/persons/
curl http://127.0.0.1:8000/contacts/persons/id/2
# do not show the next entry because it is private!
curl http://127.0.0.1:8000/contacts/persons/id/8
# do not show the next entry because it does not exist!
curl http://127.0.0.1:8000/contacts/persons/id/99
# do not show the next entry because it is private!
curl "http://127.0.0.1:8000/contacts/persons/Martin%20Schultz"
curl -X POST -H "Content-Type:application/json" -d '{"person": {"name": "Sabine Schröder", "email": "s.schroeder@fz-juelich.de", "phone": "+49-2461-61-6397", "isprivate": false}}' http://127.0.0.1:8000/contacts/persons/
# show the next entry because it is not private!
curl "http://127.0.0.1:8000/contacts/persons/Sabine%20Schr%C3%B6der"

curl http://127.0.0.1:8000/contacts/

curl http://127.0.0.1:8000/stationmeta/
curl http://127.0.0.1:8000/stationmeta/DEUB001
# do not insert the next station, because it already exists with a different code (--> station has to be patched!)
curl -X POST -H "Content-Type:application/json" -d '{"stationmeta": {"codes":["China11"],"name":"Mount Tai","coordinates":{"lat":36.256,"lng":17.106,"alt":1534.0},"coordinate_validation_status":"NotChecked","country":"CN","state":"Shandong Sheng","type":"Background","type_of_area":"Rural","category":"","timezone":"Asia/Shanghai","additional_metadata":"{}"}}' "http://127.0.0.1:8000/stationmeta/"
# station upload without nested fields (stationmeta_global will be field with requests from stationmeta_global_services)
curl -X POST -H "Content-Type:application/json" -d '{"stationmeta": {"codes":["China11"],"name":"Mount Tai","coordinates":{"lat":35.256,"lng":17.106,"alt":1534.0},"coordinate_validation_status":"NotChecked","country":"CN","state":"Shandong Sheng","type":"Background","type_of_area":"Rural","category":"","timezone":"Asia/Shanghai","additional_metadata":"{}"}}' "http://127.0.0.1:8000/stationmeta/"
# (nested) upload including 'annotations' (not defining all metadata -- getting the rest from default values) with human readable fields
curl -X POST -H "Content-Type:application/json" -d '{"stationmeta": {"codes":["CHHKG015"],"name":"Shatin","coordinates":{"lat":22.3765,"lng":114.1847,"alt":25},"coordinate_validation_status":"NotChecked","country":"CN","state":"New Territories","type":"Unknown","type_of_area":"Suburban","category":"","timezone":"Asia/Hong_Kong","additional_metadata":"{}", "roles": [{"role": "PointOfContact", "contact_id": 40, "status": "Active"},{"role": "PrincipalInvestigator", "contact_id": 41, "status": "Active"}], "annotation": {"text": "some foo","date_added":"2021-07-27","approved":true,"contributor_id":0}}}' http://127.0.0.1:8000/stationmeta/ 
#patch example (change station country)
curl -X PATCH -H 'Content-Type:application/json' -d '{"stationmeta": {"country": "US"}}' "http://127.0.0.1:8000/stationmeta/DENW200?description=add%20station%20country"

curl http://127.0.0.1:8000/timeseries/
curl http://127.0.0.1:8000/timeseries/97
# timeseries upload with (nested) human readable fields
curl -X POST -H "Content-Type:application/json" -d '{"timeseries": {"label": "", "order": 9, "access_rights": "ByAttribution", "sampling_frequency": "Irregular2", "aggregation": "Unknown", "data_origin": "Instrument", "data_start_date": "1900-01-01 00:00:00", "data_end_date": "1900-01-01 00:00:00", "data_origin_type": "Measurement", "sampling_height": 2, "date_added": "2021-09-21 15:36:47", "date_modified": "2021-09-21 15:36:47", "station_id": 1034, "variable_id": 13, "roles": [{"role": "ResourceProvider", "contact_id": 5, "status": "Active"}], "additional_metadata": "{}","data_license_accepted": "1900-01-01 00:00:00", "dataset_approved_by_provider": "1900-01-01 00:00:00"}}' "http://127.0.0.1:8000/timeseries/"
# TBD: use person_email (instead of person_id) to identify persons, f. ex. "person_email": "s.schroeder@fz-juelich.de"

# (only one of the following commands will work --> second ingestion needs to be patched!)
curl -X POST -H 'Content-Type: multipart/form-data; charset=utf-8; boundary=__X_PAW_BOUNDARY__' -F "file=@o3_CO002_2012_2017_v1-0.dat" "http://127.0.0.1:8000/data/timeseries/"
# data ingestion with automated quality control
curl -X POST -H 'Content-Type: multipart/form-data; charset=utf-8; boundary=__X_PAW_BOUNDARY__' -F "file=@o3_CO002_2012_2017_v1-0.dat" "http://127.0.0.1:8000/data/timeseries/?toarqc_config_type=standard"
curl -X PATCH -H 'Content-Type: multipart/form-data; charset=utf-8; boundary=__X_PAW_BOUNDARY__' -F "file=@o3_CO002_2012_2017_v1-0.dat" "http://127.0.0.1:8000/data/timeseries/?description=fixed%20formatting%20errors%20on%20data&version=000001.000001.00000000000000"
# add one record (including changelog entry)
curl -X POST -H "Content-Type:application/json" "http://127.0.0.1:8000/data/timeseries/record/?series_id=96&datetime=2021-08-23%2015:00:00&value=67.3&flag=OK&version=000001.000001.00000000000000"
# register list of timeseries (ids) contributing to a service request
curl -X POST -H "Content-Type:application/json" -d '''[1,2,3]''' "http://127.0.0.1:8000/timeseries/register_timeseries_list_of_contributors/5f0df73a-bd0f-48b9-bb17-d5cd36f89598"
