# -*- coding: utf-8 -*-
"""
import test data to database
============================

   populate TOAR2 database from json files via REST API
   Advantage: small database can be easily constructed

   author:
   s.schroeder@fz-juelich.de

   date: 2022/08/03

   call:
   python populate_database_via_REST.py
"""

__author__ = "Sabine Schroeder"
__version__ = "0.9"
__maintainer__ = "Sabine Schroeder"
__email__ = "s.schroeder@fz-juelich.de"


import sys
import json
import requests
import os
import os.path


TOAR_SERVICE_URL = 'http://127.0.0.1:8000/'

if __name__ == "__main__":

    # auth_user is needed!
    infilename = 'auth.json'
    with open(infilename) as f:
        metajson=json.load(f)
    print("add auth_user manually:")
    for entry in metajson:
        manual_command = "INSERT INTO auth_user (id, " 
        for key in entry:
            manual_command += f"{key}, "
        manual_command = manual_command[:-2] + ") VALUES (1, "
        for key in entry:
            manual_command += f"'{entry[key]}', "
        manual_command = manual_command[:-2] + ");"
        print(manual_command)

    # variables are fixed --> uploads have to be done manually!
    infilename = 'variables.json'
    with open(infilename) as f:
        metajson=json.load(f)
    print("add variables manually:")
    i = 1
    for entry in metajson:
        manual_command = "INSERT INTO variables(id, " 
        for key in entry:
            manual_command += f"{key}, "
        manual_command = manual_command[:-2] + f") VALUES ({i}, "
        for key in entry:
            manual_command += f"'{entry[key]}', "
        manual_command = manual_command[:-2] + ");"
        print(manual_command)
        i += 1

    # "empty" organisation and person is needed!
    print('add "empty" organisation and person manually:')
    print("INSERT INTO persons (id, name, email) VALUES (0,'','');")
    print("INSERT INTO organisations (id, name, longname, kind, city, postcode, street_address, homepage)",
          "VALUES (0, '', '', 7, '', '', '', '');")

    # endpoint for adding time series programmes is still missing --> uploads have to be done manually!
    infilename = 'timeseries_programmes.json'
    with open(infilename) as f:
        metajson=json.load(f)
    print('add time series programmes manually (at least "empty" one:')
    for entry in metajson:
        manual_command = "INSERT INTO timeseries_programmes(" 
        for key in entry:
            manual_command += f"{key}, "
        manual_command = manual_command[:-2] + f") VALUES ("
        for key in entry:
            manual_command += f"'{entry[key]}', "
        manual_command = manual_command[:-2] + ");"
        print(manual_command)

    # persons
    rest_api_url = 'contacts/persons/'
    infilename = 'persons.json'
    with open(infilename) as f:
        metajson=json.load(f)
    for entry in metajson:
        data = {"person": entry}
        requests.post(TOAR_SERVICE_URL + rest_api_url, data=json.dumps(data))

    # organisations
    rest_api_url = 'contacts/organisations/'
    infilename = 'organisations.json'
    with open(infilename) as f:
        metajson=json.load(f)
    for entry in metajson:
        data = {"organisation": entry}
        requests.post(TOAR_SERVICE_URL + rest_api_url, data=json.dumps(data))

    # stationmeta
    rest_api_url = 'stationmeta/'
    infilename = 'stationmeta_core.json'
    with open(infilename) as f:
        metajson=json.load(f)
    infilename = 'stationmeta_global.json'
    with open(infilename) as f:
        globaljson=json.load(f)
    for entry in metajson:
        stationcode = entry['codes'][0]
        station_id = entry['id']
        entry['additional_metadata'] = json.dumps(entry['additional_metadata'])
        data = {"stationmeta": entry}
        requests.post(TOAR_SERVICE_URL + rest_api_url, data=json.dumps(data))
        for entry in globaljson:
            if entry['station_id'] == station_id:
                globalmeta = {"globalmeta": entry}
                data = {"stationmeta": globalmeta}
                description = "change globalmeta according to given data"
                requests.patch(TOAR_SERVICE_URL + rest_api_url + stationcode + f'?description={description}', data=json.dumps(data))

    # time series
    rest_api_url = 'timeseries/'
    infilename = 'timeseries.json'
    with open(infilename) as f:
        metajson=json.load(f)
    for entry in metajson:
        data = {"timeseries": entry}
        print(TOAR_SERVICE_URL + rest_api_url, json.dumps(data))
        requests.post(TOAR_SERVICE_URL + rest_api_url, data=json.dumps(data))

    # data
    rest_api_url = 'data/timeseries/record/'
    infilename = 'data.json'
    with open(infilename) as f:
        metajson=json.load(f)
    for entry in metajson:
        series_id = entry['timeseries_id']
        datetime = entry['datetime']
        value = entry['value']
        flag = entry['flags']
        version = entry['version']
        requests.post(f"{TOAR_SERVICE_URL}{rest_api_url}?series_id={series_id}&datetime={datetime}&value={value}&flag={flag}&version={version}")

