# SPDX-FileCopyrightText: 2021 Forschungszentrum Jülich GmbH
# SPDX-License-Identifier: MIT

import pytest
import json
# Required imports 'create_test_database'
from toardb.test_base import (
    client,
    get_test_db,
    create_test_database,
    url,
    get_test_engine,
    test_db_session as db,
)
from toardb.stationmeta.models import StationmetaGlobalService

class TestApps:
    def setup(self):
        self.application_url = "/controlled_vocabulary"


    @pytest.fixture(autouse=True)
    def setup_db_data(self, db):
        # id_seq will not be reset automatically between tests!
        _db_conn = get_test_engine()
        infilename = "tests/fixtures/stationmeta/stationmeta_global_services.json"
        with open(infilename) as f:
            metajson=json.load(f)
            for entry in metajson:
                new_stationmeta_global_service = StationmetaGlobalService(**entry)
                db.add(new_stationmeta_global_service)
                db.commit()
                db.refresh(new_stationmeta_global_service)



    def test_get_controlled_vocabulary(self, client, db):
        response = client.get("/controlled_vocabulary")
        expected_status_code = 200
        assert response.status_code == expected_status_code
        expected_resp = {"Station Landcover Type":
                                [[-1, 'Undefined', '-1 (undefined)'],
                                 [0, 'NoData', '0 (No Data)'],
                                 [10, 'CroplandRainfed', '10 (Cropland, rainfed)'],
                                 [11, 'CroplandRainfedHerbaceousCover', '11 (Cropland, rainfed, herbaceous cover)'],
                                 [12, 'CroplandRainfedTreeOrShrubCover', '12 (Cropland, rainfed, tree or shrub cover)'],
                                 [20, 'CroplandIrrigated', '20 (Cropland, irrigated or post-flooding)'],
                                 [30, 'MosaicCropland', '30 (Mosaic cropland (>50%) / natural vegetation (tree, shrub, herbaceous cover) (<50%))'],
                                 [40, 'MosaicNaturalVegetation', '40 (Mosaic natural vegetation (tree, shrub, herbaceous cover) (>50%) / cropland (<50%))'],
                                 [50, 'TreeBroadleavedEvergreenClosedToOpen', '50 (Tree cover, broadleaved, evergreen, closed to open (>15%))'],
                                 [60, 'TreeBroadleavedDeciduousClosedToOpen', '60 (Tree cover, broadleaved, deciduous, closed to open (>15%))'],
                                 [61, 'TreeBroadleavedDeciduousClosed', '61 (Tree cover, broadleaved, deciduous, closed (>40%))'],
                                 [62, 'TreeBroadleavedDeciduousOpen', '62 (Tree cover, broadleaved, deciduous, open (15-40%))'],
                                 [70, 'TreeNeedleleavedEvergreenClosedToOpen', '70 (Tree cover, needleleaved, evergreen, closed to open (>15%))'],
                                 [71, 'TreeNeedleleavedEvergreenClosed', '71 (Tree cover, needleleaved, evergreen, closed (>40%))'],
                                 [72, 'TreeNeedleleavedEvergreenOpen', '72 (Tree cover, needleleaved, evergreen, open (15-40%))'],
                                 [80, 'TreeNeedleleavedDeciduousClosedToOpen', '80 (Tree cover, needleleaved, deciduous, closed to open (>15%))'],
                                 [81, 'TreeNedleleavedDeciduousClosed', '81 (Tree cover, needleleaved, deciduous, closed (>40%))'],
                                 [82, 'TreeNeedleleavedDeciduousOpen', '82 (Tree cover, needleleaved, deciduous, open (15-40%))'],
                                 [90, 'TreeMixed', '90 (Tree cover, mixed leaf type (broadleaved and needleleaved))'],
                                 [100, 'MosaicTreeAndShrub', '100 (Mosaic tree and shrub (>50%) / herbaceous cover (<50%))'],
                                 [110, 'MosaicHerbaceous', '110 (Mosaic herbaceous cover (>50%) / tree and shrub (<50%))'],
                                 [120, 'Shrubland', '120 (Shrubland)'],
                                 [121, 'ShrublandEvergreen', '121 (Evergreen shrubland)'],
                                 [122, 'ShrublandDeciduous', '122 (Deciduous shrubland)'],
                                 [130, 'Grassland', '130 (Grassland)'],
                                 [140, 'LichensAndMosses', '140 (Lichens and mosses)'],
                                 [150, 'SparseVegetation', '150 (Sparse vegetation (tree, shrub, herbaceous cover) (<15%))'],
                                 [151, 'SparseTree', '151 (Sparse tree (<15%))'],
                                 [152, 'SparseShrub', '152 (Sparse shrub (<15%))'],
                                 [153, 'SparseHerbaceous', '153 (Sparse herbaceous cover (<15%))'],
                                 [160, 'TreeCoverFloodedFreshOrBrakishWater', '160 (Tree cover, flooded, fresh or brakish water)'],
                                 [170, 'TreeCoverFloodedSalineWater', '170 (Tree cover, flooded, saline water)'],
                                 [180, 'ShrubOrHerbaceousCoverFlooded', '180 (Shrub or herbaceous cover, flooded, fresh/saline/brakish water)'],
                                 [190, 'Urban', '190 (Urban areas)'],
                                 [200, 'BareAreas', '200 (Bare areas)'],
                                 [201, 'BareAreasConsolidated', '201 (Consolidated bare areas)'],
                                 [202, 'BareAreasUnconsolidated', '202 (Unconsolidated bare areas)'],
                                 [210, 'Water', '210 (Water bodies)'],
                                 [220, 'SnowAndIce', '220 (Permanent snow and ice)']],
                         "Climatic Zone 2019":
                                [[-1,"Undefined","-1 (undefined)"],
                                [0,"Unclassified","0 (unclassified)"],
                                [1, 'TropicalMontane', '1 (tropical montane)'],
                                [2, 'TropicalWet', '2 (tropical wet)'],
                                [3, 'TropicalMoist', '3 (tropical moist)'],
                                [4, 'TropicalDry', '4 (tropical dry)'],
                                [5, 'WarmTemperateMoist', '5 (warm temperate moist)'],
                                [6, 'WarmTemperateDry', '6 (warm temperate dry)'],
                                [7, 'CoolTemperateMoist', '7 (cool temperate moist)'],
                                [8, 'CoolTemperateDry', '8 (cool temperate dry)'],
                                [9, 'BorealMoist', '9 (boreal moist)'],
                                [10, 'BorealDry', '10 (boreal dry)'],
                                [11, 'PolarMoist', '11 (polar moist)'],
                                [12, 'PolarDry', '12 (polar dry)']] }
        assert response.json()["Station Landcover Type"] == expected_resp["Station Landcover Type"]
        assert response.json()["Climatic Zone 2019"] == expected_resp["Climatic Zone 2019"]



    def test_get_controlled_vocabulary_field(self, client, db):
        response = client.get("/controlled_vocabulary/Station Landcover Type")
        expected_status_code = 200
        assert response.status_code == expected_status_code
        expected_resp = [[-1, 'Undefined', '-1 (undefined)'],
                         [0, 'NoData', '0 (No Data)'],
                         [10, 'CroplandRainfed', '10 (Cropland, rainfed)'],
                         [11, 'CroplandRainfedHerbaceousCover', '11 (Cropland, rainfed, herbaceous cover)'],
                         [12, 'CroplandRainfedTreeOrShrubCover', '12 (Cropland, rainfed, tree or shrub cover)'],
                         [20, 'CroplandIrrigated', '20 (Cropland, irrigated or post-flooding)'],
                         [30, 'MosaicCropland', '30 (Mosaic cropland (>50%) / natural vegetation (tree, shrub, herbaceous cover) (<50%))'],
                         [40, 'MosaicNaturalVegetation', '40 (Mosaic natural vegetation (tree, shrub, herbaceous cover) (>50%) / cropland (<50%))'],
                         [50, 'TreeBroadleavedEvergreenClosedToOpen', '50 (Tree cover, broadleaved, evergreen, closed to open (>15%))'],
                         [60, 'TreeBroadleavedDeciduousClosedToOpen', '60 (Tree cover, broadleaved, deciduous, closed to open (>15%))'],
                         [61, 'TreeBroadleavedDeciduousClosed', '61 (Tree cover, broadleaved, deciduous, closed (>40%))'],
                         [62, 'TreeBroadleavedDeciduousOpen', '62 (Tree cover, broadleaved, deciduous, open (15-40%))'],
                         [70, 'TreeNeedleleavedEvergreenClosedToOpen', '70 (Tree cover, needleleaved, evergreen, closed to open (>15%))'],
                         [71, 'TreeNeedleleavedEvergreenClosed', '71 (Tree cover, needleleaved, evergreen, closed (>40%))'],
                         [72, 'TreeNeedleleavedEvergreenOpen', '72 (Tree cover, needleleaved, evergreen, open (15-40%))'],
                         [80, 'TreeNeedleleavedDeciduousClosedToOpen', '80 (Tree cover, needleleaved, deciduous, closed to open (>15%))'],
                         [81, 'TreeNedleleavedDeciduousClosed', '81 (Tree cover, needleleaved, deciduous, closed (>40%))'],
                         [82, 'TreeNeedleleavedDeciduousOpen', '82 (Tree cover, needleleaved, deciduous, open (15-40%))'],
                         [90, 'TreeMixed', '90 (Tree cover, mixed leaf type (broadleaved and needleleaved))'],
                         [100, 'MosaicTreeAndShrub', '100 (Mosaic tree and shrub (>50%) / herbaceous cover (<50%))'],
                         [110, 'MosaicHerbaceous', '110 (Mosaic herbaceous cover (>50%) / tree and shrub (<50%))'],
                         [120, 'Shrubland', '120 (Shrubland)'],
                         [121, 'ShrublandEvergreen', '121 (Evergreen shrubland)'],
                         [122, 'ShrublandDeciduous', '122 (Deciduous shrubland)'],
                         [130, 'Grassland', '130 (Grassland)'],
                         [140, 'LichensAndMosses', '140 (Lichens and mosses)'],
                         [150, 'SparseVegetation', '150 (Sparse vegetation (tree, shrub, herbaceous cover) (<15%))'],
                         [151, 'SparseTree', '151 (Sparse tree (<15%))'],
                         [152, 'SparseShrub', '152 (Sparse shrub (<15%))'],
                         [153, 'SparseHerbaceous', '153 (Sparse herbaceous cover (<15%))'],
                         [160, 'TreeCoverFloodedFreshOrBrakishWater', '160 (Tree cover, flooded, fresh or brakish water)'],
                         [170, 'TreeCoverFloodedSalineWater', '170 (Tree cover, flooded, saline water)'],
                         [180, 'ShrubOrHerbaceousCoverFlooded', '180 (Shrub or herbaceous cover, flooded, fresh/saline/brakish water)'],
                         [190, 'Urban', '190 (Urban areas)'],
                         [200, 'BareAreas', '200 (Bare areas)'],
                         [201, 'BareAreasConsolidated', '201 (Consolidated bare areas)'],
                         [202, 'BareAreasUnconsolidated', '202 (Unconsolidated bare areas)'],
                         [210, 'Water', '210 (Water bodies)'],
                         [220, 'SnowAndIce', '220 (Permanent snow and ice)']]
        assert response.json() == expected_resp


    def test_get_controlled_vocabulary_unknown_field(self, client, db):
        response = client.get("/controlled_vocabulary/Station Landuse Type")
        expected_status_code = 200
        assert response.status_code == expected_status_code
        expected_resp = "No controlled vocabulary found for 'Station Landuse Type'"
        assert response.json() == expected_resp


    def test_get_database_statistics(self, client, db):
        response = client.get("/database_statistics")
        expected_status_code = 200
        assert response.status_code == expected_status_code
        expected_resp = {'data records': 65637800808, 'stations': 23979, 'time-series': 432880, 'users': 0}
        assert response.json() == expected_resp


    def test_get_database_statistics_field(self, client, db):
        response = client.get("/database_statistics/stations")
        expected_status_code = 200
        assert response.status_code == expected_status_code
        expected_resp = 23979
        assert response.json() == expected_resp


    def test_get_geopeas_urls(self, client, db):
        response = client.get("/geopeas_urls")
        expected_status_code = 200
        assert response.status_code == expected_status_code
        expected_resp = [
                         {
                           "service_url":"{base_url}/climatic_zone/?lat={lat}&lon={lon}",
                           "variable_name":"climatic_zone_year2016"
                         },
                         {
                           "service_url":"{base_url}/major_road/?lat={lat}&lon={lon}",
                           "variable_name":"distance_to_major_road_year2020"
                         },
                         {
                           "service_url":"{base_url}/population_density/?year=2015&lat={lat}&lon={lon}",
                           "variable_name":"mean_population_density_250m_year2015"
                         },
                         {
                           "service_url":"{base_url}/population_density/?year=2015&lat={lat}&lon={lon}",
                           "variable_name":"mean_population_density_5km_year2015"
                         },
                         {
                           "service_url":"{base_url}/population_density/?agg=max&radius=25000&year=2015&lat={lat}&lon={lon}",
                           "variable_name":"max_population_density_25km_year2015"
                         },
                         {
                           "service_url":"{base_url}/population_density/?agg=mean&radius=250&year=1990&lat={lat}&lon={lon}",
                           "variable_name":"mean_population_density_250m_year1990"
                         },
                         {
                           "service_url":"{base_url}/population_density/?agg=mean&radius=5000&year=1990&lat={lat}&lon={lon}",
                           "variable_name":"mean_population_density_5km_year1990"
                         },
                         {
                           "service_url":"{base_url}/population_density/?agg=max&radius=25000&year=1990&lat={lat}&lon={lon}",
                           "variable_name":"max_population_density_25km_year1990"
                         },
                         {
                           "service_url":"{base_url}/nox_emissions/?year=2015&lat={lat}&lon={lon}",
                           "variable_name":"mean_nox_emissions_10km_year2015"
                         },
                         {
                           "service_url":"{base_url}/nox_emissions/?year=2000&lat={lat}&lon={lon}",
                           "variable_name":"mean_nox_emissions_10km_year2000"
                         },
                         {
                           "service_url":"{base_url}/htap_region_tier1/?lat={lat}&country={country}",
                           "variable_name":"htap_region_tier1_year2010"
                         },
                         {
                           "service_url":"{base_url}/ecoregion/?description=false&lat={lat}&lon={lon}",
                           "variable_name":"dominant_ecoregion_year2017"
                         },
                         {
                           "service_url":"{base_url}/landcover/?year=2012&description=false&lat={lat}&lon={lon}",
                           "variable_name":"dominant_landcover_year2012"
                         },
                         {
                           "service_url":"{base_url}/ecoregion/?description=true&radius=25000&lat={lat}&lon={lon}",
                           "variable_name":"ecoregion_description_25km_year2017"
                         },
                         {
                           "service_url":"{base_url}/landcover/?year=2012&radius=25000&description=true&lat={lat}&lon={lon}",
                           "variable_name":"landcover_description_25km_year2012"
                         },
                         {
                           "service_url":"{base_url}/topography_srtm/?relative=false&lat={lat}&lon={lon}",
                           "variable_name":"mean_topography_srtm_alt_90m_year1994"
                         },
                         {
                           "service_url":"{base_url}/topography_srtm/?relative=false&agg=mean&radius=1000&lat={lat}&lon={lon}",
                           "variable_name":"mean_topography_srtm_alt_1km_year1994"
                         },
                         {
                           "service_url":"{base_url}/topography_srtm/?relative=true&agg=max&radius=5000&lat={lat}&lon={lon}",
                           "variable_name":"max_topography_srtm_relative_alt_5km_year1994"
                         },
                         {
                           "service_url":"{base_url}/topography_srtm/?relative=true&agg=min&radius=5000&lat={lat}&lon={lon}",
                           "variable_name":"min_topography_srtm_relative_alt_5km_year1994"
                         },
                         {
                           "service_url":"{base_url}/topography_srtm/?relative=true&agg=stddev&radius=5000&lat={lat}&lon={lon}",
                           "variable_name":"stddev_topography_srtm_relative_alt_5km_year1994"
                         },
                         {
                           "service_url":"{base_url}/stable_nightlights/?year=2013&lat={lat}&lon={lon}",
                           "variable_name":"mean_stable_nightlights_1km_year2013"
                         },
                         {
                           "service_url":"{base_url}/stable_nightlights/?agg=mean&radius=5000&year=2013&lat={lat}&lon={lon}",
                           "variable_name":"mean_stable_nightlights_5km_year2013"
                         },
                         {
                           "service_url":"{base_url}/stable_nightlights/?agg=max&radius=25000&year=2013&lat={lat}&lon={lon}",
                           "variable_name":"max_stable_nightlights_25km_year2013"
                         },
                         {
                           "service_url":"{base_url}/stable_nightlights/?agg=max&radius=25000&year=1992&lat={lat}&lon={lon}",
                           "variable_name":"max_stable_nightlights_25km_year1992"
                         }
                       ]
        set_expected_resp = {json.dumps(item, sort_keys=True) for item in expected_resp}
        set_response = {json.dumps(item, sort_keys=True) for item in response.json()}
        assert set_response == set_expected_resp
