from fastapi import APIRouter, Depends, HTTPException, Request, Query
from typing import List
from sqlalchemy.orm import Session

from . import crud, schemas
from toardb.utils.database import get_db

router = APIRouter()

#get all metadata of one person
@router.get('/auth_user/')
def get_eduperson(request: Request, eduperson_unique_id: str = None, DoIncr: str = "0,0", db: Session = Depends(get_db)):
    try:
        parts = [int(x) for x in DoIncr.split(",")]
    except ValueError:
        raise HTTPException(status_code=400, detail="Parameter 'DoIncr' must contain two integers, separated by a comma.")

    if len(parts) != 2:
        raise HTTPException(status_code=400, detail="Parameter 'DoIncr' must contain exactly two values.")
    db_person = crud.get_eduperson_and_roles(request, eduperson_unique_id=eduperson_unique_id, DoIncr=parts)
    if db_person is None:
        raise HTTPException(status_code=404, detail="Eduperson not found.")
    return db_person


#determine increments (number of time series/gridded products of a given request)
@router.get('/auth_user/increments/')
def get_increments(request: Request, db: Session = Depends(get_db), user_role=None):
    return crud.determine_increments(request, db, user_role=user_role)
