# SPDX-FileCopyrightText: 2021 Forschungszentrum Jülich GmbH
# SPDX-License-Identifier: MIT

"""
Pydantic schemas for TOAR database

"""

from typing import List, Any

from pydantic import BaseModel, validator, Field, Json
import datetime as dt
import toardb

class DataBase(BaseModel):
    datetime: dt.datetime = Field(..., description="date and time of observation")
    value: float = Field(..., description="variable value at datetime")
    flags: str = Field(..., description="flag (see controlled vocabulary: Data Flag)")
    timeseries_id: int = Field(..., description="ID of timeseries")
    version: str = Field(..., description="version")

    @validator('flags')
    def check_flags(cls, v):
        try:
            return tuple(filter(lambda x: x.value == int(v), toardb.toardb.DF_vocabulary))[0].display_str
        except:
            return v

    @validator('version')
    def convert_version(cls, v):
        try:
            major,minor,micro = v.split('.')
            if int(micro) != 0:
                return f"{int(major)}.{int(minor)}.{int(micro)}"
            else:
                return f"{int(major)}.{int(minor)}"
        except:
            return v


class DataPatch(DataBase):
    pass

    @validator('flags')
    def check_flags(cls, v):
        return int(v)

    @validator('version')
    def convert_version(cls, v):
        # do not touch version string!
        return v


class DataCreate(DataBase):
    pass

    @validator('flags')
    def check_flags(cls, v):
        return int(v)


    @validator('version')
    def convert_version(cls, v):
        # do not touch version string!
        return v


class Data(DataBase):
    datetime: dt.datetime = None
    value: float = None
    flags: str = None
    timeseries_id: int = None
    version: str = None

    class Config:
        orm_mode = True


class Composite(BaseModel):
    metadata: Any = Field(..., description="all metadata available to the data")
    data: List[Data] = Field(..., description="the data itself")

