# SPDX-FileCopyrightText: 2021 Forschungszentrum Jülich GmbH
# SPDX-License-Identifier: MIT

from sqlalchemy import Table, Column, Integer, String
from sqlalchemy.ext.declarative import declarative_base
from .models_core import StationmetaCore
from .models_global import StationmetaGlobal
from .models_global_services import StationmetaGlobalService
from .models_role import StationmetaRole, stationmeta_core_stationmeta_roles_table
from .models_annotation import StationmetaAnnotation, stationmeta_core_stationmeta_annotations_table
from .models_aux import StationmetaAuxDoc, StationmetaAuxImage, StationmetaAuxUrl
from .models_changelog import StationmetaChangelog

from toardb.base import Base

# controlled vocabulary

# Station Climatic Zone
CZ_enum_table = Table("cz_vocabulary",
    Base.metadata,
    Column("enum_val", Integer, primary_key=True),
    Column("enum_str", String),
    Column("enum_display_str", String)
)

# Station Coordinate Validity
CV_enum_table = Table("cv_vocabulary",
    Base.metadata,
    Column("enum_val", Integer, primary_key=True),
    Column("enum_str", String),
    Column("enum_display_str", String)
)

# Station Types 
ST_enum_table = Table("st_vocabulary",
    Base.metadata,
    Column("enum_val", Integer, primary_key=True),
    Column("enum_str", String),
    Column("enum_display_str", String)
)

# Station Types of Area
TA_enum_table = Table("ta_vocabulary",
    Base.metadata,
    Column("enum_val", Integer, primary_key=True),
    Column("enum_str", String),
    Column("enum_display_str", String)
)

# Station TOAR Categories
TC_enum_table = Table("tc_vocabulary",
    Base.metadata,
    Column("enum_val", Integer, primary_key=True),
    Column("enum_str", String),
    Column("enum_display_str", String)
)

# Station HTAP Regions (TIER1)
TR_enum_table = Table("tr_vocabulary",
    Base.metadata,
    Column("enum_val", Integer, primary_key=True),
    Column("enum_str", String),
    Column("enum_display_str", String)
)

# Station Dominant Landcover Types
LC_enum_table = Table("lc_vocabulary",
    Base.metadata,
    Column("enum_val", Integer, primary_key=True),
    Column("enum_str", String),
    Column("enum_display_str", String)
)

# Station ECO Region Types
ER_enum_table = Table("er_vocabulary",
    Base.metadata,
    Column("enum_val", Integer, primary_key=True),
    Column("enum_str", String),
    Column("enum_display_str", String)
)

# Result Types
RT_enum_table = Table("rt_vocabulary",
    Base.metadata,
    Column("enum_val", Integer, primary_key=True),
    Column("enum_str", String),
    Column("enum_display_str", String)
)

# Country names 
CN_enum_table = Table("cn_vocabulary",
    Base.metadata,
    Column("enum_val", Integer, primary_key=True),
    Column("enum_str", String),
    Column("enum_display_str", String)
)

# Timezones
TZ_enum_table = Table("tz_vocabulary",
    Base.metadata,
    Column("enum_val", Integer, primary_key=True),
    Column("enum_str", String),
    Column("enum_display_str", String)
)

