import TOARII_ontology
import argparse
import csv
import os
"""
the script adds entries to a given class of the ontology and outputs a new ontology file

--onto [filepath.jsonld]
    filepath of the ontology to which the entries should be added
--add [filepath.txt]
    filepath of the file containing the entries to be added
    the file should look like this:
        string1; display_string1
        string2; display_string2
        ...
--cl [classname]
    classname of the onology to which the entries should be added
--out [filepath<.jsonld>]
    outputs the configured ontology file with a given filename")
"""

def parse_args():
    parser = argparse.ArgumentParser()
    parser.add_argument("--onto", type=str, help="[filepath.jsonld] using the given an ontology file")
    parser.add_argument("--add", type=str, help="[filepath.txt] input entries of file into refering ontology class named like 'filename'")
    parser.add_argument("--cl", type=str, help="[classname] classname of the onology to which the entries should be added")
    parser.add_argument("--out", type=str, help="[filepath<.jsonld>] outputs the configured ontology file with a given filename")
    args = parser.parse_args()

    if not args.onto:
        print("no given path to an ontology file")
        exit(-1)

    if not os.path.isfile(args.onto): #or not args.onto.endswith(".owl"):
        print("the given path to the ontology file is incorrect")
        exit(-1)

    if not args.cl:
        print("no classname given")
        exit(-1)

    if args.add:
        if not os.path.isfile(args.add) or not args.add.endswith(".txt"):
            print("the given path to the adding file is incorrect")
            exit(-1)

    if not args.out:
        print("no output file mentioned")
        exit(-1)

    else:
        if not args.out.endswith(".jsonld"):
            args.out += ".jsonld"

    return args

if __name__ == "__main__":
    args = parse_args()
    onto = TOARII_ontology.TOAR_Ontology(args.onto)
    onto_classname = args.cl
    adding_file = args.add
    output_file = args.out

    # read the adding file
    with open(adding_file, "r") as input_file:
        reader = csv.reader(input_file, delimiter=";")

        # cuts off the fileextension to use the filename as classname for the ontology
        #onto_classname = onto.get_class(adding_file[:-4])
        if not onto_classname in onto.get_classes():
            print(f"class name '{onto_classname}' is not included in the ontology")
            exit(-1)

        index = onto.get_next_id()
        start_index = index
        existing_entrys = onto.getEntries(onto_classname)
        #print(existing_entrys)

        for line in reader:
            # line[0]: enum string
            # line[1]: enum display string
            enum_str = line[0]
            enum_display_str = line[1]
            #print(enum_str, enum_display_str, index)
            if not onto.check_entry(enum_str, onto_classname):
                onto.add_entry(ont_class=onto_classname, label=enum_str, definition=enum_display_str, idcount=index)
                index += 1

        print(f"added {index - start_index} entrys to classname '{onto_classname}'")

    onto.save(filename=output_file, format="json-ld")
    print(f"new ontology file '{output_file}' created")