#!/bin/bash

###
# ECO region translation table preprocessing
# ==========================================
#
# author: Sabine Schroeder (s.schroeder@fz-juelich.de)
# date: 2021/12/13
#
# This script is started by
#     prepare_ECO_regions_for_controlled_vocabulary.sh
#
###

while read LINE
do
  ECO_DESCR=`echo ${LINE} | cut -f1 -d';'`
  ECO_ID=`echo ${LINE} | cut -f2 -d';'`
  ECO_ABBREV=`echo ${ECO_DESCR} | sed 's/ //g' | \
	                          sed 's/,//g' | \
	                          sed 's/\.//g' | \
	                          sed "s/'//g" | \
	                          sed 's/-//g' | \
	                          sed 's$/$$g' | \
	                          sed 's/&/And/g' | \
				  sed 's/á/a/g' | \
				  sed 's/é/e/g' | \
				  sed 's/í/i/g' | \
          			  sed 's/ó/o/g' | \
				  sed 's/ú/u/g' | \
				  sed 's/ã/a/g' | \
				  sed 's/õ/o/g' | \
				  sed 's/ñ/n/g' | \
				  sed 's/ç/c/g'`
  ECO_DESCR=`echo ${ECO_DESCR} | sed "s/'/''/g"`
# if [[ $ECO_ABBREV = *[![:ascii:]]* ]]; then
#   echo "${ECO_ABBREV} contains Non-ASCII"
# fi
  if ! [[ ${ECO_ABBREV} =~ ^[A-Za-z]*$ ]]; then
    echo "${ECO_ABBREV} contains Non-characters"
  fi
  printf "    (%3d, '%s', '%d (%s)'),\n" ${ECO_ID} "${ECO_ABBREV}" ${ECO_ID} "${ECO_DESCR}" >> tmp.psql
done < <(cut -f2,8 -d';' ECO_Regions_translate_table.csv | tail +2)

# now write complete psql file (sorted)
echo "CREATE TABLE IF NOT EXISTS ER_vocabulary (" > ECO_vocabulary.psql
echo "    enum_val         INT NOT NULL," >> ECO_vocabulary.psql
echo "    enum_str         character varying(128) NOT NULL, " >> ECO_vocabulary.psql
echo "    enum_display_str character varying(128) NOT NULL, " >> ECO_vocabulary.psql
echo "    PRIMARY KEY(enum_val, enum_str)," >> ECO_vocabulary.psql
echo "    CONSTRAINT rc_enum_val_unique UNIQUE (enum_val)" >> ECO_vocabulary.psql
echo ");" >> ECO_vocabulary.psql
echo >> ECO_vocabulary.psql
echo "INSERT INTO ER_vocabulary (enum_val, enum_str, enum_display_str) VALUES" >> ECO_vocabulary.psql
cat tmp.psql | sort -u | sed '$s/\(.*\),/\1;/' >> ECO_vocabulary.psql
rm tmp.psql
