#!/usr/bin/python3
# -*- coding: utf-8 -*-
"""
OWLDoc preprocessing
====================

see:  https://gitlab.version.fz-juelich.de/esde/toar-data/toardb_fastapi/-/issues/41

deleting all lines
    from the line after the first </div><!-- types (1) --> line
    and including the last but one line <div id='label_(1)'>
"""

__author__ = "Sabine Schroeder"
__version__ = "0.5"
__date__ = "2021/12/15"
__maintainer__ = "Sabine Schroeder"
__email__ = "s.schroeder@fz-juelich.de"

import sys
import os
import getopt


def usage():
    msg = ["Usage: prepare_OWLDoc.py options",
           "Options:   -h, --help              help",
           "           -f, --filename  str     filename"]
    print("\n".join([m for m in msg]))


def get_options(argv):
    """analyse command line options and argument"""

    long_opt = ["help", "filename="]
    try:
        opts, args = getopt.gnu_getopt(argv, "hf:", long_opt)
    except getopt.GetoptError as e:
        print(str(e))
        usage()
        sys.exit(2)
    filename = ''
    for o, a in opts:
        if o in ("-h", "--help"):
            usage()
            sys.exit()
        elif o in ("-f", "--filename"):
            filename = a
    if filename == '':
        usage()
        sys.exit(2)
    return filename


def shrink_file(filename):

    # open input file
    rd = open (filename, "r")

    # open output file

    wr = open ("../individuals/"+filename, "w")

    # read list of lines
    lines = rd.readlines()

    # determine lines to copy to output file
    index_head = 0
    try: 
#       index_head = lines.index("</div><!-- types (1)'>\n") + 1
        index_head = min(index for index, item in enumerate(lines) if "</div><!-- types (" in item) + 1
    except ValueError as e:
        pass
    if index_head  == 0:
        print (f"no 'types_(n)' found for file {filename} --> unchanged")
        for line in lines:
            wr.write(line)
    else:
        index_label = max(index for index, item in enumerate(lines) if item == "<div id='label_(1)'>\n") - 1
        # check whether related comment or isdefinedby exists
        try: 
            # does comment tag exists at all?
            index_comment = max(index for index, item in enumerate(lines) if item == "<div id='comment_(1)'>\n") - 1
        except:
            index_comment = 0
        try: 
            # does isdefinedby tag exists at all?
            index_isdefinedby = max(index for index, item in enumerate(lines) if item == "<div id='isdefinedby_(1)'>\n") - 1
        except:
            index_isdefinedby = 0
        index_tail = index_label
        if (index_label - index_comment) < 30:
            index_tail = index_comment
        if (index_label - index_isdefinedby) < 30:
            index_tail = min(index_tail,index_isdefinedby)
        # for double check: debugging output
        if index_tail != index_label:
            print(f"found comment or isdefinedby for file {filename}.")
        for i in range(index_head+1):
            wr.write(lines[i]) 
        for i in range(index_tail+1,len(lines),1):
            wr.write(lines[i]) 

    # Close file 
    rd.close()


if __name__ == "__main__":

    filename = get_options(sys.argv)
    shrink_file(filename)
    
