"""
read a combined time series from the TOAR-II database
=====================================================

   - use a given catalogue to combine timeseries from the TOAR-II database

   author:
   s.schroeder@fz-juelich.de

   date: 2024/03/11

   call:
   python example.py -s species -p provider -c stcode
   or
   python example.py --species species --provider provider --stcode stcode
   (f. ex. python example.py -s o3 -p EEA -c ES1920Apython example.py -s o3 -p EEA -c ES1920A)
"""

__author__ = "Sabine Schroeder"
__version__ = "0.9"
__maintainer__ = "Sabine Schroeder"
__email__ = "s.schroeder@fz-juelich.de"

import json
import requests
import argparse

TOAR_SERVICE_URL = "https://toar-data.fz-juelich.de/api/v2/"


def read_catalogue(catfilename): 
    with open(catfilename) as f:
        catalogue = json.load(f)
    return catalogue


if __name__ == "__main__":

    # get the command line arguments
    parser = argparse.ArgumentParser()
    parser.add_argument('-s', '--species',  help='species to be extracted (f. ex. o3)')
    parser.add_argument('-p', '--provider', help='provider of the time series to be extracted (f. ex. EEA)')
    parser.add_argument('-c', '--stcode',   help='station code to be extracted (f. ex. ES1920A)')
    args = parser.parse_args()
    species = args.species
    provider = args.provider
    stcode = args.stcode

    # read the catalogue
    catfilename = "combined_timeseries.json"
    catalogue = read_catalogue(catfilename)

    # get the data
    for drange in catalogue[species][stcode][provider]:
        data = requests.get(f"{TOAR_SERVICE_URL}data/timeseries/{drange[2]}?daterange={drange[0]},{drange[1]}&format=csv")
        # have a look at this page to see how to deal with the csv-data:
        # https://toar-data.fz-juelich.de/api/v2/#python-example


        # plots for existing time series can easily be done with the dashboard tools, f. ex.:
        # https://zam2061.zam.kfa-juelich.de/plots?plot_type=ts-plot-seperated&timeseries=40870,41250,41309
        # https://zam2061.zam.kfa-juelich.de/plots?plot_type=ts-plot-combined&timeseries=40870,41250,41309
