# SPDX-FileCopyrightText: 2021 Forschungszentrum Jülich GmbH
# SPDX-License-Identifier: MIT

"""
Create, Read, Update, Delete functionality

"""

from fastapi.responses import JSONResponse
from sqlalchemy import text
from sqlalchemy.orm import Session
from . import models, schemas
from toardb.utils.utils import create_filter


def get_variable(db: Session, variable_id: int):
    return (
        db.query(models.Variable)
        .filter(models.Variable.id == variable_id)
        .first()
    )


def get_variable_by_name(db: Session, name: str):
    return (
        db.query(models.Variable)
        .filter(models.Variable.name == name.lower())
        .first()
    )


def get_variables(db: Session, path_params, query_params):
    try:
        limit, offset, fields, format, filters = create_filter(
            query_params, "variables"
        )
        v_filter = filters["v_filter"]
    except (KeyError, ValueError) as e:
        status_code = 400
        return JSONResponse(status_code=status_code, content=str(e))

    if fields:
        fields2 = fields.split(",")
        db_objects_l = (
            db.query(*map(text, fields2))
            .select_from(models.Variable)
            .filter(text(v_filter))
            .order_by(models.Variable.id)
            .limit(limit)
            .offset(offset)
        )
        db_objects = []
        for db_object_immut in db_objects_l:
            db_object = dict(zip(fields.split(","), db_object_immut))
            db_objects.append(db_object)
    else:
        db_objects = (
            db.query(models.Variable)
            .filter(text(v_filter))
            .order_by(models.Variable.id)
            .offset(offset)
            .limit(limit)
            .all()
        )
    return db_objects


def create_variable(db: Session, variable: schemas.VariableCreate):
    db_variable = models.Variable(**variable.dict())
    db.add(db_variable)
    db.commit()
    db.refresh(db_variable)
    return db_variable
