# SPDX-FileCopyrightText: 2021 Forschungszentrum Jülich GmbH
# SPDX-License-Identifier: MIT

"""
Pydantic schemas for TOAR database

"""

from pydantic import BaseModel, Field


class VariableBase(BaseModel):
    name: str = Field(
        None, description="Name. Short variable-like name of the variable"
    )
    longname: str = Field(
        None, description="Longname. Long (explicit) name of the variable"
    )
    displayname: str = Field(
        None, description="Displayname. Display name of the variable"
    )
    cf_standardname: str = Field(
        None, description="Cf standardname. "
                          + "CF standard name of the variable if defined"
    )
    units: str = Field(None, description="Units. Physical units of variable")
    chemical_formula: str = Field(
        None,
        description="Chemical formula. "
                    + "Chemical formula of variable(if applicable)",
    )


class VariableCreate(VariableBase):
    pass


class Variable(VariableBase):
    id: int = None

    class Config:
        orm_mode = True
