# SPDX-FileCopyrightText: 2021 Forschungszentrum Jülich GmbH
# SPDX-License-Identifier: MIT

"""
Simple test API for variable management
"""

from typing import List
from fastapi import APIRouter, Depends, HTTPException, Request
from sqlalchemy.orm import Session
from toardb.variables import crud, schemas
from toardb.utils.database import get_db

router = APIRouter()


# plain views to post and get variables
@router.post("/variables/", response_model=schemas.Variable)
def create_variable(
    variable: schemas.VariableCreate, db: Session = Depends(get_db)
):
    db_variable = crud.get_variable_by_name(db, name=variable.name)
    if db_variable:
        raise HTTPException(
            status_code=400, detail="Variable already registered."
        )
    return crud.create_variable(db=db, variable=variable)


@router.get(
    "/variables/",
    response_model=List[schemas.Variable],
    response_model_exclude_none=True,
    response_model_exclude_unset=True,
)
def get_variables(request: Request, db: Session = Depends(get_db)):
    variables = crud.get_variables(
        db, path_params=request.path_params, query_params=request.query_params
    )
    return variables


@router.get("/variables/{name}", response_model=schemas.Variable)
def get_variable_by_name(name: str, db: Session = Depends(get_db)):
    db_variable = crud.get_variable_by_name(db, name=name)
    if db_variable is None:
        raise HTTPException(status_code=404, detail="Variable not found.")
    return db_variable


@router.get("/variables/id/{variable_id}", response_model=schemas.Variable)
def get_variable_by_id(variable_id: int, db: Session = Depends(get_db)):
    db_variable = crud.get_variable(db, variable_id=variable_id)
    if db_variable is None:
        raise HTTPException(status_code=404, detail="Variable not found.")
    return db_variable
